==> jc-1.4.0.tar.gz: gnu/xml/pipeline/ValidationConsumer__24ElementInfo.h <==
// final class gnu.xml.pipeline.ValidationConsumer$ElementInfo

// class file dependencies
// @dep_class 9289b07357331d38 gnu_xml_pipeline_ValidationConsumer__24ElementInfo
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_ValidationConsumer__24ElementInfo_H_
#define _JC_gnu_xml_pipeline_ValidationConsumer__24ElementInfo_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_ValidationConsumer$object;
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_refs	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$refs	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object;

typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vmethods	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vmethods;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtable	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtable;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtype	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$method$getRecognizer$179dfbfe08c472c2(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer$object *);
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$method_info$getRecognizer$179dfbfe08c472c2;
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vmethods {
	struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object	*(*getRecognizer$179dfbfe08c472c2)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *);
};

// Vtable
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vmethods	gnu_xml_pipeline_ValidationConsumer__24ElementInfo;
};

// Vtype
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*model;
	struct _jc_java_util_Hashtable$object	*attributes;
	struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object	*recognizer;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$refs {
    _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_refs	gnu_xml_pipeline_ValidationConsumer__24ElementInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24ElementInfo;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object {
	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtype	*vtype;
	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtype _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_ValidationConsumer__24ElementInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$class_object;

#endif	/* _JC_gnu_xml_pipeline_ValidationConsumer__24ElementInfo_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/ValidationConsumer__24ElementInfo.h <==
// final class gnu.xml.pipeline.ValidationConsumer$ElementInfo

// class file dependencies
// @dep_class 9289b07357331d38 gnu_xml_pipeline_ValidationConsumer__24ElementInfo
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_ValidationConsumer__24ElementInfo_H_
#define _JC_gnu_xml_pipeline_ValidationConsumer__24ElementInfo_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_ValidationConsumer$object;
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_refs	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$refs	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object;

typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vmethods	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vmethods;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtable	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtable;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtype	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$method$getRecognizer$179dfbfe08c472c2(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$method_info$getRecognizer$179dfbfe08c472c2;
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vmethods {
	struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object	*(*getRecognizer$179dfbfe08c472c2)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vmethods	gnu_xml_pipeline_ValidationConsumer__24ElementInfo;
};

// Vtype
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*model;
	struct _jc_java_util_Hashtable$object	*attributes;
	struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object	*recognizer;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$refs {
    _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_refs	gnu_xml_pipeline_ValidationConsumer__24ElementInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24ElementInfo;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object {
	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtype	*vtype;
	_jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$vtype _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_ValidationConsumer__24ElementInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$class_object;

#endif	/* _JC_gnu_xml_pipeline_ValidationConsumer__24ElementInfo_H_ */
